@@ -57,7 +57,9 @@ from .searching import (
 )
 
 from .sequences import (
+    concat,
     pop_n,
+    replace_range,
 )
 
 from .combining import (
@@ -68,6 +70,7 @@ __all__ = [
     "alternate_with",
     "append",
     "append_if",
+    "concat",
     "duplicates",
     "ensure_contains",
     "expand_numbered_list",
@@ -88,6 +91,7 @@ __all__ = [
     "reject_if",
     "reject_truthy",
     "repeat_first",
+    "replace_range",
     "retain_falsy",
     "retain_if",
     "retain_truthy",
